# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_greengrass.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_greengrass.proto\x12\x1aoak9.tython.aws.greengrass\x1a\x13shared/shared.proto\"\x8b\x02\n\x1c\x43onnectorDefinitionConnector\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rconnector_arn\x18\x02 \x01(\t\x12\\\n\nparameters\x18\x03 \x03(\x0b\x32H.oak9.tython.aws.greengrass.ConnectorDefinitionConnector.ParametersEntry\x12\n\n\x02id\x18\x04 \x01(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x01\n-ConnectorDefinitionConnectorDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12L\n\nconnectors\x18\x02 \x03(\x0b\x32\x38.oak9.tython.aws.greengrass.ConnectorDefinitionConnector\"\xb6\x02\n\x13\x43onnectorDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n\x0finitial_version\x18\x02 \x01(\x0b\x32I.oak9.tython.aws.greengrass.ConnectorDefinitionConnectorDefinitionVersion\x12G\n\x04tags\x18\x03 \x03(\x0b\x32\x39.oak9.tython.aws.greengrass.ConnectorDefinition.TagsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\n\n\nGreengrass\x12M\n\x14\x63onnector_definition\x18\x01 \x03(\x0b\x32/.oak9.tython.aws.greengrass.ConnectorDefinition\x12\\\n\x1c\x63onnector_definition_version\x18\x02 \x03(\x0b\x32\x36.oak9.tython.aws.greengrass.ConnectorDefinitionVersion\x12\x43\n\x0f\x63ore_definition\x18\x03 \x03(\x0b\x32*.oak9.tython.aws.greengrass.CoreDefinition\x12R\n\x17\x63ore_definition_version\x18\x04 \x03(\x0b\x32\x31.oak9.tython.aws.greengrass.CoreDefinitionVersion\x12G\n\x11\x64\x65vice_definition\x18\x05 \x03(\x0b\x32,.oak9.tython.aws.greengrass.DeviceDefinition\x12V\n\x19\x64\x65vice_definition_version\x18\x06 \x03(\x0b\x32\x33.oak9.tython.aws.greengrass.DeviceDefinitionVersion\x12K\n\x13\x66unction_definition\x18\x07 \x03(\x0b\x32..oak9.tython.aws.greengrass.FunctionDefinition\x12Z\n\x1b\x66unction_definition_version\x18\x08 \x03(\x0b\x32\x35.oak9.tython.aws.greengrass.FunctionDefinitionVersion\x12\x30\n\x05group\x18\t \x03(\x0b\x32!.oak9.tython.aws.greengrass.Group\x12?\n\rgroup_version\x18\n \x03(\x0b\x32(.oak9.tython.aws.greengrass.GroupVersion\x12G\n\x11logger_definition\x18\x0b \x03(\x0b\x32,.oak9.tython.aws.greengrass.LoggerDefinition\x12V\n\x19logger_definition_version\x18\x0c \x03(\x0b\x32\x33.oak9.tython.aws.greengrass.LoggerDefinitionVersion\x12K\n\x13resource_definition\x18\r \x03(\x0b\x32..oak9.tython.aws.greengrass.ResourceDefinition\x12Z\n\x1bresource_definition_version\x18\x0e \x03(\x0b\x32\x35.oak9.tython.aws.greengrass.ResourceDefinitionVersion\x12S\n\x17subscription_definition\x18\x0f \x03(\x0b\x32\x32.oak9.tython.aws.greengrass.SubscriptionDefinition\x12\x62\n\x1fsubscription_definition_version\x18\x10 \x03(\x0b\x32\x39.oak9.tython.aws.greengrass.SubscriptionDefinitionVersion\"\x99\x02\n#ConnectorDefinitionVersionConnector\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rconnector_arn\x18\x02 \x01(\t\x12\x63\n\nparameters\x18\x03 \x03(\x0b\x32O.oak9.tython.aws.greengrass.ConnectorDefinitionVersionConnector.ParametersEntry\x12\n\n\x02id\x18\x04 \x01(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcb\x01\n\x1a\x43onnectorDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\nconnectors\x18\x02 \x03(\x0b\x32?.oak9.tython.aws.greengrass.ConnectorDefinitionVersionConnector\x12\x1f\n\x17\x63onnector_definition_id\x18\x03 \x01(\t\"\x9a\x01\n\x12\x43oreDefinitionCore\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsync_shadow\x18\x02 \x01(\x08\x12\x11\n\tthing_arn\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x05 \x01(\t\"\x9d\x01\n#CoreDefinitionCoreDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x05\x63ores\x18\x02 \x03(\x0b\x32..oak9.tython.aws.greengrass.CoreDefinitionCore\"\xa2\x02\n\x0e\x43oreDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12X\n\x0finitial_version\x18\x02 \x01(\x0b\x32?.oak9.tython.aws.greengrass.CoreDefinitionCoreDefinitionVersion\x12\x42\n\x04tags\x18\x03 \x03(\x0b\x32\x34.oak9.tython.aws.greengrass.CoreDefinition.TagsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa1\x01\n\x19\x43oreDefinitionVersionCore\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsync_shadow\x18\x02 \x01(\x08\x12\x11\n\tthing_arn\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x05 \x01(\t\"\xb2\x01\n\x15\x43oreDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\x05\x63ores\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.greengrass.CoreDefinitionVersionCore\x12\x1a\n\x12\x63ore_definition_id\x18\x03 \x01(\t\"\x9e\x01\n\x16\x44\x65viceDefinitionDevice\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsync_shadow\x18\x02 \x01(\x08\x12\x11\n\tthing_arn\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x05 \x01(\t\"\xa7\x01\n\'DeviceDefinitionDeviceDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x43\n\x07\x64\x65vices\x18\x02 \x03(\x0b\x32\x32.oak9.tython.aws.greengrass.DeviceDefinitionDevice\"\xaa\x02\n\x10\x44\x65viceDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\\\n\x0finitial_version\x18\x02 \x01(\x0b\x32\x43.oak9.tython.aws.greengrass.DeviceDefinitionDeviceDefinitionVersion\x12\x44\n\x04tags\x18\x03 \x03(\x0b\x32\x36.oak9.tython.aws.greengrass.DeviceDefinition.TagsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa5\x01\n\x1d\x44\x65viceDefinitionVersionDevice\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsync_shadow\x18\x02 \x01(\x08\x12\x11\n\tthing_arn\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x05 \x01(\t\"\xbc\x01\n\x17\x44\x65viceDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x64\x65vice_definition_id\x18\x02 \x01(\t\x12J\n\x07\x64\x65vices\x18\x03 \x03(\x0b\x32\x39.oak9.tython.aws.greengrass.DeviceDefinitionVersionDevice\"l\n\x17\x46unctionDefinitionRunAs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03uid\x18\x02 \x01(\x05\x12\x0b\n\x03gid\x18\x03 \x01(\x05\"\xb3\x01\n\x1b\x46unctionDefinitionExecution\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eisolation_mode\x18\x02 \x01(\t\x12\x43\n\x06run_as\x18\x03 \x01(\x0b\x32\x33.oak9.tython.aws.greengrass.FunctionDefinitionRunAs\"\xa6\x01\n\x1f\x46unctionDefinitionDefaultConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12J\n\texecution\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.greengrass.FunctionDefinitionExecution\"\x8a\x01\n&FunctionDefinitionResourceAccessPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x12\n\npermission\x18\x03 \x01(\t\"\xaf\x03\n\x1d\x46unctionDefinitionEnvironment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12[\n\tvariables\x18\x02 \x03(\x0b\x32H.oak9.tython.aws.greengrass.FunctionDefinitionEnvironment.VariablesEntry\x12J\n\texecution\x18\x03 \x01(\x0b\x32\x37.oak9.tython.aws.greengrass.FunctionDefinitionExecution\x12\x64\n\x18resource_access_policies\x18\x04 \x03(\x0b\x32\x42.oak9.tython.aws.greengrass.FunctionDefinitionResourceAccessPolicy\x12\x14\n\x0c\x61\x63\x63\x65ss_sysfs\x18\x05 \x01(\x08\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa6\x02\n\'FunctionDefinitionFunctionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmemory_size\x18\x02 \x01(\x05\x12\x0e\n\x06pinned\x18\x03 \x01(\x08\x12\x11\n\texec_args\x18\x04 \x01(\t\x12\x0f\n\x07timeout\x18\x05 \x01(\x05\x12\x15\n\rencoding_type\x18\x06 \x01(\t\x12N\n\x0b\x65nvironment\x18\x07 \x01(\x0b\x32\x39.oak9.tython.aws.greengrass.FunctionDefinitionEnvironment\x12\x12\n\nexecutable\x18\x08 \x01(\t\"\xdc\x01\n\x1a\x46unctionDefinitionFunction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x66unction_arn\x18\x02 \x01(\t\x12\x63\n\x16\x66unction_configuration\x18\x03 \x01(\x0b\x32\x43.oak9.tython.aws.greengrass.FunctionDefinitionFunctionConfiguration\x12\n\n\x02id\x18\x04 \x01(\t\"\x86\x02\n+FunctionDefinitionFunctionDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\x0e\x64\x65\x66\x61ult_config\x18\x02 \x01(\x0b\x32;.oak9.tython.aws.greengrass.FunctionDefinitionDefaultConfig\x12I\n\tfunctions\x18\x03 \x03(\x0b\x32\x36.oak9.tython.aws.greengrass.FunctionDefinitionFunction\"\xb2\x02\n\x12\x46unctionDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12`\n\x0finitial_version\x18\x02 \x01(\x0b\x32G.oak9.tython.aws.greengrass.FunctionDefinitionFunctionDefinitionVersion\x12\x46\n\x04tags\x18\x03 \x03(\x0b\x32\x38.oak9.tython.aws.greengrass.FunctionDefinition.TagsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"s\n\x1e\x46unctionDefinitionVersionRunAs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03uid\x18\x02 \x01(\x05\x12\x0b\n\x03gid\x18\x03 \x01(\x05\"\xc1\x01\n\"FunctionDefinitionVersionExecution\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eisolation_mode\x18\x02 \x01(\t\x12J\n\x06run_as\x18\x03 \x01(\x0b\x32:.oak9.tython.aws.greengrass.FunctionDefinitionVersionRunAs\"\xb4\x01\n&FunctionDefinitionVersionDefaultConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Q\n\texecution\x18\x02 \x01(\x0b\x32>.oak9.tython.aws.greengrass.FunctionDefinitionVersionExecution\"\x91\x01\n-FunctionDefinitionVersionResourceAccessPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x12\n\npermission\x18\x03 \x01(\t\"\xcb\x03\n$FunctionDefinitionVersionEnvironment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n\tvariables\x18\x02 \x03(\x0b\x32O.oak9.tython.aws.greengrass.FunctionDefinitionVersionEnvironment.VariablesEntry\x12Q\n\texecution\x18\x03 \x01(\x0b\x32>.oak9.tython.aws.greengrass.FunctionDefinitionVersionExecution\x12k\n\x18resource_access_policies\x18\x04 \x03(\x0b\x32I.oak9.tython.aws.greengrass.FunctionDefinitionVersionResourceAccessPolicy\x12\x14\n\x0c\x61\x63\x63\x65ss_sysfs\x18\x05 \x01(\x08\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb4\x02\n.FunctionDefinitionVersionFunctionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmemory_size\x18\x02 \x01(\x05\x12\x0e\n\x06pinned\x18\x03 \x01(\x08\x12\x11\n\texec_args\x18\x04 \x01(\t\x12\x0f\n\x07timeout\x18\x05 \x01(\x05\x12\x15\n\rencoding_type\x18\x06 \x01(\t\x12U\n\x0b\x65nvironment\x18\x07 \x01(\x0b\x32@.oak9.tython.aws.greengrass.FunctionDefinitionVersionEnvironment\x12\x12\n\nexecutable\x18\x08 \x01(\t\"\xea\x01\n!FunctionDefinitionVersionFunction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x66unction_arn\x18\x02 \x01(\t\x12j\n\x16\x66unction_configuration\x18\x03 \x01(\x0b\x32J.oak9.tython.aws.greengrass.FunctionDefinitionVersionFunctionConfiguration\x12\n\n\x02id\x18\x04 \x01(\t\"\xa2\x02\n\x19\x46unctionDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Z\n\x0e\x64\x65\x66\x61ult_config\x18\x02 \x01(\x0b\x32\x42.oak9.tython.aws.greengrass.FunctionDefinitionVersionDefaultConfig\x12P\n\tfunctions\x18\x03 \x03(\x0b\x32=.oak9.tython.aws.greengrass.FunctionDefinitionVersionFunction\x12\x1e\n\x16\x66unction_definition_id\x18\x04 \x01(\t\"\xe8\x02\n\x11GroupGroupVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12%\n\x1dlogger_definition_version_arn\x18\x02 \x01(\t\x12%\n\x1d\x64\x65vice_definition_version_arn\x18\x03 \x01(\t\x12\'\n\x1f\x66unction_definition_version_arn\x18\x04 \x01(\t\x12#\n\x1b\x63ore_definition_version_arn\x18\x05 \x01(\t\x12\'\n\x1fresource_definition_version_arn\x18\x06 \x01(\t\x12(\n connector_definition_version_arn\x18\x07 \x01(\t\x12+\n#subscription_definition_version_arn\x18\x08 \x01(\t\"\x90\x02\n\x05Group\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x46\n\x0finitial_version\x18\x02 \x01(\x0b\x32-.oak9.tython.aws.greengrass.GroupGroupVersion\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x39\n\x04tags\x18\x04 \x03(\x0b\x32+.oak9.tython.aws.greengrass.Group.TagsEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf5\x02\n\x0cGroupVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12%\n\x1dlogger_definition_version_arn\x18\x02 \x01(\t\x12%\n\x1d\x64\x65vice_definition_version_arn\x18\x03 \x01(\t\x12\'\n\x1f\x66unction_definition_version_arn\x18\x04 \x01(\t\x12#\n\x1b\x63ore_definition_version_arn\x18\x05 \x01(\t\x12\'\n\x1fresource_definition_version_arn\x18\x06 \x01(\t\x12(\n connector_definition_version_arn\x18\x07 \x01(\t\x12+\n#subscription_definition_version_arn\x18\x08 \x01(\t\x12\x10\n\x08group_id\x18\t \x01(\t\"\x8e\x01\n\x16LoggerDefinitionLogger\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05space\x18\x02 \x01(\x05\x12\r\n\x05level\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x11\n\tcomponent\x18\x05 \x01(\t\"\xa7\x01\n\'LoggerDefinitionLoggerDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x43\n\x07loggers\x18\x02 \x03(\x0b\x32\x32.oak9.tython.aws.greengrass.LoggerDefinitionLogger\"\xaa\x02\n\x10LoggerDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\\\n\x0finitial_version\x18\x02 \x01(\x0b\x32\x43.oak9.tython.aws.greengrass.LoggerDefinitionLoggerDefinitionVersion\x12\x44\n\x04tags\x18\x03 \x03(\x0b\x32\x36.oak9.tython.aws.greengrass.LoggerDefinition.TagsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x95\x01\n\x1dLoggerDefinitionVersionLogger\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05space\x18\x02 \x01(\x05\x12\r\n\x05level\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x11\n\tcomponent\x18\x05 \x01(\t\"\xbc\x01\n\x17LoggerDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14logger_definition_id\x18\x02 \x01(\t\x12J\n\x07loggers\x18\x03 \x03(\x0b\x32\x39.oak9.tython.aws.greengrass.LoggerDefinitionVersionLogger\"\xa9\x01\n2ResourceDefinitionSecretsManagerSecretResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12-\n%additional_staging_labels_to_download\x18\x03 \x03(\t\"\x98\x01\n.ResourceDefinitionResourceDownloadOwnerSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bgroup_owner\x18\x02 \x01(\t\x12\x18\n\x10group_permission\x18\x03 \x01(\t\"\x8f\x02\n;ResourceDefinitionSageMakerMachineLearningModelResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x61\n\rowner_setting\x18\x02 \x01(\x0b\x32J.oak9.tython.aws.greengrass.ResourceDefinitionResourceDownloadOwnerSetting\x12\x18\n\x10\x64\x65stination_path\x18\x03 \x01(\t\x12\x1a\n\x12sage_maker_job_arn\x18\x04 \x01(\t\"\x91\x01\n#ResourceDefinitionGroupOwnerSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x61uto_add_group_owner\x18\x02 \x01(\x08\x12\x13\n\x0bgroup_owner\x18\x03 \x01(\t\"\xf1\x01\n)ResourceDefinitionLocalVolumeResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsource_path\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x03 \x01(\t\x12\\\n\x13group_owner_setting\x18\x04 \x01(\x0b\x32?.oak9.tython.aws.greengrass.ResourceDefinitionGroupOwnerSetting\"\xd7\x01\n)ResourceDefinitionLocalDeviceResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsource_path\x18\x02 \x01(\t\x12\\\n\x13group_owner_setting\x18\x03 \x01(\x0b\x32?.oak9.tython.aws.greengrass.ResourceDefinitionGroupOwnerSetting\"\xfc\x01\n4ResourceDefinitionS3MachineLearningModelResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x61\n\rowner_setting\x18\x02 \x01(\x0b\x32J.oak9.tython.aws.greengrass.ResourceDefinitionResourceDownloadOwnerSetting\x12\x18\n\x10\x64\x65stination_path\x18\x03 \x01(\t\x12\x0e\n\x06s3_uri\x18\x04 \x01(\t\"\xcd\x05\n\'ResourceDefinitionResourceDataContainer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12|\n$secrets_manager_secret_resource_data\x18\x02 \x01(\x0b\x32N.oak9.tython.aws.greengrass.ResourceDefinitionSecretsManagerSecretResourceData\x12\x90\x01\n/sage_maker_machine_learning_model_resource_data\x18\x03 \x01(\x0b\x32W.oak9.tython.aws.greengrass.ResourceDefinitionSageMakerMachineLearningModelResourceData\x12i\n\x1alocal_volume_resource_data\x18\x04 \x01(\x0b\x32\x45.oak9.tython.aws.greengrass.ResourceDefinitionLocalVolumeResourceData\x12i\n\x1alocal_device_resource_data\x18\x05 \x01(\x0b\x32\x45.oak9.tython.aws.greengrass.ResourceDefinitionLocalDeviceResourceData\x12\x81\x01\n\'s3_machine_learning_model_resource_data\x18\x06 \x01(\x0b\x32P.oak9.tython.aws.greengrass.ResourceDefinitionS3MachineLearningModelResourceData\"\xdd\x01\n\"ResourceDefinitionResourceInstance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x64\n\x17resource_data_container\x18\x02 \x01(\x0b\x32\x43.oak9.tython.aws.greengrass.ResourceDefinitionResourceDataContainer\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xb9\x01\n+ResourceDefinitionResourceDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Q\n\tresources\x18\x02 \x03(\x0b\x32>.oak9.tython.aws.greengrass.ResourceDefinitionResourceInstance\"\xb2\x02\n\x12ResourceDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12`\n\x0finitial_version\x18\x02 \x01(\x0b\x32G.oak9.tython.aws.greengrass.ResourceDefinitionResourceDefinitionVersion\x12\x46\n\x04tags\x18\x03 \x03(\x0b\x32\x38.oak9.tython.aws.greengrass.ResourceDefinition.TagsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb0\x01\n9ResourceDefinitionVersionSecretsManagerSecretResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12-\n%additional_staging_labels_to_download\x18\x03 \x03(\t\"\x9f\x01\n5ResourceDefinitionVersionResourceDownloadOwnerSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bgroup_owner\x18\x02 \x01(\t\x12\x18\n\x10group_permission\x18\x03 \x01(\t\"\x9d\x02\nBResourceDefinitionVersionSageMakerMachineLearningModelResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12h\n\rowner_setting\x18\x02 \x01(\x0b\x32Q.oak9.tython.aws.greengrass.ResourceDefinitionVersionResourceDownloadOwnerSetting\x12\x18\n\x10\x64\x65stination_path\x18\x03 \x01(\t\x12\x1a\n\x12sage_maker_job_arn\x18\x04 \x01(\t\"\x98\x01\n*ResourceDefinitionVersionGroupOwnerSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x61uto_add_group_owner\x18\x02 \x01(\x08\x12\x13\n\x0bgroup_owner\x18\x03 \x01(\t\"\xff\x01\n0ResourceDefinitionVersionLocalVolumeResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsource_path\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x03 \x01(\t\x12\x63\n\x13group_owner_setting\x18\x04 \x01(\x0b\x32\x46.oak9.tython.aws.greengrass.ResourceDefinitionVersionGroupOwnerSetting\"\xe5\x01\n0ResourceDefinitionVersionLocalDeviceResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsource_path\x18\x02 \x01(\t\x12\x63\n\x13group_owner_setting\x18\x03 \x01(\x0b\x32\x46.oak9.tython.aws.greengrass.ResourceDefinitionVersionGroupOwnerSetting\"\x8a\x02\n;ResourceDefinitionVersionS3MachineLearningModelResourceData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12h\n\rowner_setting\x18\x02 \x01(\x0b\x32Q.oak9.tython.aws.greengrass.ResourceDefinitionVersionResourceDownloadOwnerSetting\x12\x18\n\x10\x64\x65stination_path\x18\x03 \x01(\t\x12\x0e\n\x06s3_uri\x18\x04 \x01(\t\"\xf8\x05\n.ResourceDefinitionVersionResourceDataContainer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x83\x01\n$secrets_manager_secret_resource_data\x18\x02 \x01(\x0b\x32U.oak9.tython.aws.greengrass.ResourceDefinitionVersionSecretsManagerSecretResourceData\x12\x97\x01\n/sage_maker_machine_learning_model_resource_data\x18\x03 \x01(\x0b\x32^.oak9.tython.aws.greengrass.ResourceDefinitionVersionSageMakerMachineLearningModelResourceData\x12p\n\x1alocal_volume_resource_data\x18\x04 \x01(\x0b\x32L.oak9.tython.aws.greengrass.ResourceDefinitionVersionLocalVolumeResourceData\x12p\n\x1alocal_device_resource_data\x18\x05 \x01(\x0b\x32L.oak9.tython.aws.greengrass.ResourceDefinitionVersionLocalDeviceResourceData\x12\x88\x01\n\'s3_machine_learning_model_resource_data\x18\x06 \x01(\x0b\x32W.oak9.tython.aws.greengrass.ResourceDefinitionVersionS3MachineLearningModelResourceData\"\xeb\x01\n)ResourceDefinitionVersionResourceInstance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12k\n\x17resource_data_container\x18\x02 \x01(\x0b\x32J.oak9.tython.aws.greengrass.ResourceDefinitionVersionResourceDataContainer\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xce\x01\n\x19ResourceDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12X\n\tresources\x18\x02 \x03(\x0b\x32\x45.oak9.tython.aws.greengrass.ResourceDefinitionVersionResourceInstance\x12\x1e\n\x16resource_definition_id\x18\x03 \x01(\t\"\x9a\x01\n\"SubscriptionDefinitionSubscription\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06target\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x0f\n\x07subject\x18\x05 \x01(\t\"\xc5\x01\n3SubscriptionDefinitionSubscriptionDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12U\n\rsubscriptions\x18\x02 \x03(\x0b\x32>.oak9.tython.aws.greengrass.SubscriptionDefinitionSubscription\"\xc2\x02\n\x16SubscriptionDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12h\n\x0finitial_version\x18\x02 \x01(\x0b\x32O.oak9.tython.aws.greengrass.SubscriptionDefinitionSubscriptionDefinitionVersion\x12J\n\x04tags\x18\x03 \x03(\x0b\x32<.oak9.tython.aws.greengrass.SubscriptionDefinition.TagsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa1\x01\n)SubscriptionDefinitionVersionSubscription\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06target\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x0f\n\x07subject\x18\x05 \x01(\t\"\xda\x01\n\x1dSubscriptionDefinitionVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\"\n\x1asubscription_definition_id\x18\x02 \x01(\t\x12\\\n\rsubscriptions\x18\x03 \x03(\x0b\x32\x45.oak9.tython.aws.greengrass.SubscriptionDefinitionVersionSubscriptionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_greengrass_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONNECTORDEFINITIONCONNECTOR_PARAMETERSENTRY._options = None
  _CONNECTORDEFINITIONCONNECTOR_PARAMETERSENTRY._serialized_options = b'8\001'
  _CONNECTORDEFINITION_TAGSENTRY._options = None
  _CONNECTORDEFINITION_TAGSENTRY._serialized_options = b'8\001'
  _CONNECTORDEFINITIONVERSIONCONNECTOR_PARAMETERSENTRY._options = None
  _CONNECTORDEFINITIONVERSIONCONNECTOR_PARAMETERSENTRY._serialized_options = b'8\001'
  _COREDEFINITION_TAGSENTRY._options = None
  _COREDEFINITION_TAGSENTRY._serialized_options = b'8\001'
  _DEVICEDEFINITION_TAGSENTRY._options = None
  _DEVICEDEFINITION_TAGSENTRY._serialized_options = b'8\001'
  _FUNCTIONDEFINITIONENVIRONMENT_VARIABLESENTRY._options = None
  _FUNCTIONDEFINITIONENVIRONMENT_VARIABLESENTRY._serialized_options = b'8\001'
  _FUNCTIONDEFINITION_TAGSENTRY._options = None
  _FUNCTIONDEFINITION_TAGSENTRY._serialized_options = b'8\001'
  _FUNCTIONDEFINITIONVERSIONENVIRONMENT_VARIABLESENTRY._options = None
  _FUNCTIONDEFINITIONVERSIONENVIRONMENT_VARIABLESENTRY._serialized_options = b'8\001'
  _GROUP_TAGSENTRY._options = None
  _GROUP_TAGSENTRY._serialized_options = b'8\001'
  _LOGGERDEFINITION_TAGSENTRY._options = None
  _LOGGERDEFINITION_TAGSENTRY._serialized_options = b'8\001'
  _RESOURCEDEFINITION_TAGSENTRY._options = None
  _RESOURCEDEFINITION_TAGSENTRY._serialized_options = b'8\001'
  _SUBSCRIPTIONDEFINITION_TAGSENTRY._options = None
  _SUBSCRIPTIONDEFINITION_TAGSENTRY._serialized_options = b'8\001'
  _CONNECTORDEFINITIONCONNECTOR._serialized_start=78
  _CONNECTORDEFINITIONCONNECTOR._serialized_end=345
  _CONNECTORDEFINITIONCONNECTOR_PARAMETERSENTRY._serialized_start=296
  _CONNECTORDEFINITIONCONNECTOR_PARAMETERSENTRY._serialized_end=345
  _CONNECTORDEFINITIONCONNECTORDEFINITIONVERSION._serialized_start=348
  _CONNECTORDEFINITIONCONNECTORDEFINITIONVERSION._serialized_end=530
  _CONNECTORDEFINITION._serialized_start=533
  _CONNECTORDEFINITION._serialized_end=843
  _CONNECTORDEFINITION_TAGSENTRY._serialized_start=800
  _CONNECTORDEFINITION_TAGSENTRY._serialized_end=843
  _GREENGRASS._serialized_start=846
  _GREENGRASS._serialized_end=2144
  _CONNECTORDEFINITIONVERSIONCONNECTOR._serialized_start=2147
  _CONNECTORDEFINITIONVERSIONCONNECTOR._serialized_end=2428
  _CONNECTORDEFINITIONVERSIONCONNECTOR_PARAMETERSENTRY._serialized_start=296
  _CONNECTORDEFINITIONVERSIONCONNECTOR_PARAMETERSENTRY._serialized_end=345
  _CONNECTORDEFINITIONVERSION._serialized_start=2431
  _CONNECTORDEFINITIONVERSION._serialized_end=2634
  _COREDEFINITIONCORE._serialized_start=2637
  _COREDEFINITIONCORE._serialized_end=2791
  _COREDEFINITIONCOREDEFINITIONVERSION._serialized_start=2794
  _COREDEFINITIONCOREDEFINITIONVERSION._serialized_end=2951
  _COREDEFINITION._serialized_start=2954
  _COREDEFINITION._serialized_end=3244
  _COREDEFINITION_TAGSENTRY._serialized_start=800
  _COREDEFINITION_TAGSENTRY._serialized_end=843
  _COREDEFINITIONVERSIONCORE._serialized_start=3247
  _COREDEFINITIONVERSIONCORE._serialized_end=3408
  _COREDEFINITIONVERSION._serialized_start=3411
  _COREDEFINITIONVERSION._serialized_end=3589
  _DEVICEDEFINITIONDEVICE._serialized_start=3592
  _DEVICEDEFINITIONDEVICE._serialized_end=3750
  _DEVICEDEFINITIONDEVICEDEFINITIONVERSION._serialized_start=3753
  _DEVICEDEFINITIONDEVICEDEFINITIONVERSION._serialized_end=3920
  _DEVICEDEFINITION._serialized_start=3923
  _DEVICEDEFINITION._serialized_end=4221
  _DEVICEDEFINITION_TAGSENTRY._serialized_start=800
  _DEVICEDEFINITION_TAGSENTRY._serialized_end=843
  _DEVICEDEFINITIONVERSIONDEVICE._serialized_start=4224
  _DEVICEDEFINITIONVERSIONDEVICE._serialized_end=4389
  _DEVICEDEFINITIONVERSION._serialized_start=4392
  _DEVICEDEFINITIONVERSION._serialized_end=4580
  _FUNCTIONDEFINITIONRUNAS._serialized_start=4582
  _FUNCTIONDEFINITIONRUNAS._serialized_end=4690
  _FUNCTIONDEFINITIONEXECUTION._serialized_start=4693
  _FUNCTIONDEFINITIONEXECUTION._serialized_end=4872
  _FUNCTIONDEFINITIONDEFAULTCONFIG._serialized_start=4875
  _FUNCTIONDEFINITIONDEFAULTCONFIG._serialized_end=5041
  _FUNCTIONDEFINITIONRESOURCEACCESSPOLICY._serialized_start=5044
  _FUNCTIONDEFINITIONRESOURCEACCESSPOLICY._serialized_end=5182
  _FUNCTIONDEFINITIONENVIRONMENT._serialized_start=5185
  _FUNCTIONDEFINITIONENVIRONMENT._serialized_end=5616
  _FUNCTIONDEFINITIONENVIRONMENT_VARIABLESENTRY._serialized_start=5568
  _FUNCTIONDEFINITIONENVIRONMENT_VARIABLESENTRY._serialized_end=5616
  _FUNCTIONDEFINITIONFUNCTIONCONFIGURATION._serialized_start=5619
  _FUNCTIONDEFINITIONFUNCTIONCONFIGURATION._serialized_end=5913
  _FUNCTIONDEFINITIONFUNCTION._serialized_start=5916
  _FUNCTIONDEFINITIONFUNCTION._serialized_end=6136
  _FUNCTIONDEFINITIONFUNCTIONDEFINITIONVERSION._serialized_start=6139
  _FUNCTIONDEFINITIONFUNCTIONDEFINITIONVERSION._serialized_end=6401
  _FUNCTIONDEFINITION._serialized_start=6404
  _FUNCTIONDEFINITION._serialized_end=6710
  _FUNCTIONDEFINITION_TAGSENTRY._serialized_start=800
  _FUNCTIONDEFINITION_TAGSENTRY._serialized_end=843
  _FUNCTIONDEFINITIONVERSIONRUNAS._serialized_start=6712
  _FUNCTIONDEFINITIONVERSIONRUNAS._serialized_end=6827
  _FUNCTIONDEFINITIONVERSIONEXECUTION._serialized_start=6830
  _FUNCTIONDEFINITIONVERSIONEXECUTION._serialized_end=7023
  _FUNCTIONDEFINITIONVERSIONDEFAULTCONFIG._serialized_start=7026
  _FUNCTIONDEFINITIONVERSIONDEFAULTCONFIG._serialized_end=7206
  _FUNCTIONDEFINITIONVERSIONRESOURCEACCESSPOLICY._serialized_start=7209
  _FUNCTIONDEFINITIONVERSIONRESOURCEACCESSPOLICY._serialized_end=7354
  _FUNCTIONDEFINITIONVERSIONENVIRONMENT._serialized_start=7357
  _FUNCTIONDEFINITIONVERSIONENVIRONMENT._serialized_end=7816
  _FUNCTIONDEFINITIONVERSIONENVIRONMENT_VARIABLESENTRY._serialized_start=5568
  _FUNCTIONDEFINITIONVERSIONENVIRONMENT_VARIABLESENTRY._serialized_end=5616
  _FUNCTIONDEFINITIONVERSIONFUNCTIONCONFIGURATION._serialized_start=7819
  _FUNCTIONDEFINITIONVERSIONFUNCTIONCONFIGURATION._serialized_end=8127
  _FUNCTIONDEFINITIONVERSIONFUNCTION._serialized_start=8130
  _FUNCTIONDEFINITIONVERSIONFUNCTION._serialized_end=8364
  _FUNCTIONDEFINITIONVERSION._serialized_start=8367
  _FUNCTIONDEFINITIONVERSION._serialized_end=8657
  _GROUPGROUPVERSION._serialized_start=8660
  _GROUPGROUPVERSION._serialized_end=9020
  _GROUP._serialized_start=9023
  _GROUP._serialized_end=9295
  _GROUP_TAGSENTRY._serialized_start=800
  _GROUP_TAGSENTRY._serialized_end=843
  _GROUPVERSION._serialized_start=9298
  _GROUPVERSION._serialized_end=9671
  _LOGGERDEFINITIONLOGGER._serialized_start=9674
  _LOGGERDEFINITIONLOGGER._serialized_end=9816
  _LOGGERDEFINITIONLOGGERDEFINITIONVERSION._serialized_start=9819
  _LOGGERDEFINITIONLOGGERDEFINITIONVERSION._serialized_end=9986
  _LOGGERDEFINITION._serialized_start=9989
  _LOGGERDEFINITION._serialized_end=10287
  _LOGGERDEFINITION_TAGSENTRY._serialized_start=800
  _LOGGERDEFINITION_TAGSENTRY._serialized_end=843
  _LOGGERDEFINITIONVERSIONLOGGER._serialized_start=10290
  _LOGGERDEFINITIONVERSIONLOGGER._serialized_end=10439
  _LOGGERDEFINITIONVERSION._serialized_start=10442
  _LOGGERDEFINITIONVERSION._serialized_end=10630
  _RESOURCEDEFINITIONSECRETSMANAGERSECRETRESOURCEDATA._serialized_start=10633
  _RESOURCEDEFINITIONSECRETSMANAGERSECRETRESOURCEDATA._serialized_end=10802
  _RESOURCEDEFINITIONRESOURCEDOWNLOADOWNERSETTING._serialized_start=10805
  _RESOURCEDEFINITIONRESOURCEDOWNLOADOWNERSETTING._serialized_end=10957
  _RESOURCEDEFINITIONSAGEMAKERMACHINELEARNINGMODELRESOURCEDATA._serialized_start=10960
  _RESOURCEDEFINITIONSAGEMAKERMACHINELEARNINGMODELRESOURCEDATA._serialized_end=11231
  _RESOURCEDEFINITIONGROUPOWNERSETTING._serialized_start=11234
  _RESOURCEDEFINITIONGROUPOWNERSETTING._serialized_end=11379
  _RESOURCEDEFINITIONLOCALVOLUMERESOURCEDATA._serialized_start=11382
  _RESOURCEDEFINITIONLOCALVOLUMERESOURCEDATA._serialized_end=11623
  _RESOURCEDEFINITIONLOCALDEVICERESOURCEDATA._serialized_start=11626
  _RESOURCEDEFINITIONLOCALDEVICERESOURCEDATA._serialized_end=11841
  _RESOURCEDEFINITIONS3MACHINELEARNINGMODELRESOURCEDATA._serialized_start=11844
  _RESOURCEDEFINITIONS3MACHINELEARNINGMODELRESOURCEDATA._serialized_end=12096
  _RESOURCEDEFINITIONRESOURCEDATACONTAINER._serialized_start=12099
  _RESOURCEDEFINITIONRESOURCEDATACONTAINER._serialized_end=12816
  _RESOURCEDEFINITIONRESOURCEINSTANCE._serialized_start=12819
  _RESOURCEDEFINITIONRESOURCEINSTANCE._serialized_end=13040
  _RESOURCEDEFINITIONRESOURCEDEFINITIONVERSION._serialized_start=13043
  _RESOURCEDEFINITIONRESOURCEDEFINITIONVERSION._serialized_end=13228
  _RESOURCEDEFINITION._serialized_start=13231
  _RESOURCEDEFINITION._serialized_end=13537
  _RESOURCEDEFINITION_TAGSENTRY._serialized_start=800
  _RESOURCEDEFINITION_TAGSENTRY._serialized_end=843
  _RESOURCEDEFINITIONVERSIONSECRETSMANAGERSECRETRESOURCEDATA._serialized_start=13540
  _RESOURCEDEFINITIONVERSIONSECRETSMANAGERSECRETRESOURCEDATA._serialized_end=13716
  _RESOURCEDEFINITIONVERSIONRESOURCEDOWNLOADOWNERSETTING._serialized_start=13719
  _RESOURCEDEFINITIONVERSIONRESOURCEDOWNLOADOWNERSETTING._serialized_end=13878
  _RESOURCEDEFINITIONVERSIONSAGEMAKERMACHINELEARNINGMODELRESOURCEDATA._serialized_start=13881
  _RESOURCEDEFINITIONVERSIONSAGEMAKERMACHINELEARNINGMODELRESOURCEDATA._serialized_end=14166
  _RESOURCEDEFINITIONVERSIONGROUPOWNERSETTING._serialized_start=14169
  _RESOURCEDEFINITIONVERSIONGROUPOWNERSETTING._serialized_end=14321
  _RESOURCEDEFINITIONVERSIONLOCALVOLUMERESOURCEDATA._serialized_start=14324
  _RESOURCEDEFINITIONVERSIONLOCALVOLUMERESOURCEDATA._serialized_end=14579
  _RESOURCEDEFINITIONVERSIONLOCALDEVICERESOURCEDATA._serialized_start=14582
  _RESOURCEDEFINITIONVERSIONLOCALDEVICERESOURCEDATA._serialized_end=14811
  _RESOURCEDEFINITIONVERSIONS3MACHINELEARNINGMODELRESOURCEDATA._serialized_start=14814
  _RESOURCEDEFINITIONVERSIONS3MACHINELEARNINGMODELRESOURCEDATA._serialized_end=15080
  _RESOURCEDEFINITIONVERSIONRESOURCEDATACONTAINER._serialized_start=15083
  _RESOURCEDEFINITIONVERSIONRESOURCEDATACONTAINER._serialized_end=15843
  _RESOURCEDEFINITIONVERSIONRESOURCEINSTANCE._serialized_start=15846
  _RESOURCEDEFINITIONVERSIONRESOURCEINSTANCE._serialized_end=16081
  _RESOURCEDEFINITIONVERSION._serialized_start=16084
  _RESOURCEDEFINITIONVERSION._serialized_end=16290
  _SUBSCRIPTIONDEFINITIONSUBSCRIPTION._serialized_start=16293
  _SUBSCRIPTIONDEFINITIONSUBSCRIPTION._serialized_end=16447
  _SUBSCRIPTIONDEFINITIONSUBSCRIPTIONDEFINITIONVERSION._serialized_start=16450
  _SUBSCRIPTIONDEFINITIONSUBSCRIPTIONDEFINITIONVERSION._serialized_end=16647
  _SUBSCRIPTIONDEFINITION._serialized_start=16650
  _SUBSCRIPTIONDEFINITION._serialized_end=16972
  _SUBSCRIPTIONDEFINITION_TAGSENTRY._serialized_start=800
  _SUBSCRIPTIONDEFINITION_TAGSENTRY._serialized_end=843
  _SUBSCRIPTIONDEFINITIONVERSIONSUBSCRIPTION._serialized_start=16975
  _SUBSCRIPTIONDEFINITIONVERSIONSUBSCRIPTION._serialized_end=17136
  _SUBSCRIPTIONDEFINITIONVERSION._serialized_start=17139
  _SUBSCRIPTIONDEFINITIONVERSION._serialized_end=17357
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_spanner_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_spanner_pb2 as gcp_dot_gcp__spanner__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#gcp/gcp_google_spanner_bundle.proto\x12%oak9.tython.gcp.google_spanner_bundle\x1a\x13shared/shared.proto\x1a\x15gcp/gcp_spanner.proto\"\xab\x05\n\rGoogleSpanner\x12\x42\n\x10spanner_database\x18\x01 \x03(\x0b\x32(.oak9.tython.gcp.spanner.SpannerDatabase\x12X\n\x1cspanner_database_iam_binding\x18\x02 \x03(\x0b\x32\x32.oak9.tython.gcp.spanner.SpannerDatabaseIamBinding\x12V\n\x1bspanner_database_iam_member\x18\x03 \x03(\x0b\x32\x31.oak9.tython.gcp.spanner.SpannerDatabaseIamMember\x12V\n\x1bspanner_database_iam_policy\x18\x04 \x03(\x0b\x32\x31.oak9.tython.gcp.spanner.SpannerDatabaseIamPolicy\x12\x42\n\x10spanner_instance\x18\x05 \x01(\x0b\x32(.oak9.tython.gcp.spanner.SpannerInstance\x12X\n\x1cspanner_instance_iam_binding\x18\x06 \x03(\x0b\x32\x32.oak9.tython.gcp.spanner.SpannerInstanceIamBinding\x12V\n\x1bspanner_instance_iam_member\x18\x07 \x03(\x0b\x32\x31.oak9.tython.gcp.spanner.SpannerInstanceIamMember\x12V\n\x1bspanner_instance_iam_policy\x18\x08 \x03(\x0b\x32\x31.oak9.tython.gcp.spanner.SpannerInstanceIamPolicyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_spanner_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLESPANNER._serialized_start=123
  _GOOGLESPANNER._serialized_end=806
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_securityhub.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61ws/aws_securityhub.proto\x12\x1boak9.tython.aws.securityhub\x1a\x13shared/shared.proto\"\xa5\x01\n\x03Hub\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x38\n\x04tags\x18\x02 \x03(\x0b\x32*.oak9.tython.aws.securityhub.Hub.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"<\n\x0bSecurityHub\x12-\n\x03hub\x18\x01 \x03(\x0b\x32 .oak9.tython.aws.securityhub.Hubb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_securityhub_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _HUB_TAGSENTRY._options = None
  _HUB_TAGSENTRY._serialized_options = b'8\001'
  _HUB._serialized_start=80
  _HUB._serialized_end=245
  _HUB_TAGSENTRY._serialized_start=202
  _HUB_TAGSENTRY._serialized_end=245
  _SECURITYHUB._serialized_start=247
  _SECURITYHUB._serialized_end=307
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_transfer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61ws/aws_transfer.proto\x12\x18oak9.tython.aws.transfer\x1a\x13shared/shared.proto\"I\n\x0eServerProtocol\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"~\n\x1dServerIdentityProviderDetails\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0finvocation_role\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\"\xad\x01\n\x15ServerEndpointDetails\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x61\x64\x64ress_allocation_ids\x18\x02 \x03(\t\x12\x0e\n\x06vpc_id\x18\x03 \x01(\t\x12\x17\n\x0fvpc_endpoint_id\x18\x04 \x01(\t\x12\x12\n\nsubnet_ids\x18\x05 \x03(\t\"\x8c\x04\n\x06Server\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0clogging_role\x18\x02 \x01(\t\x12;\n\tprotocols\x18\x03 \x03(\x0b\x32(.oak9.tython.aws.transfer.ServerProtocol\x12Z\n\x19identity_provider_details\x18\x04 \x01(\x0b\x32\x37.oak9.tython.aws.transfer.ServerIdentityProviderDetails\x12\x15\n\rendpoint_type\x18\x05 \x01(\t\x12\x1c\n\x14security_policy_name\x18\x06 \x01(\t\x12I\n\x10\x65ndpoint_details\x18\x07 \x01(\x0b\x32/.oak9.tython.aws.transfer.ServerEndpointDetails\x12\x1e\n\x16identity_provider_type\x18\x08 \x01(\t\x12\x38\n\x04tags\x18\t \x03(\x0b\x32*.oak9.tython.aws.transfer.Server.TagsEntry\x12\x13\n\x0b\x63\x65rtificate\x18\n \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"j\n\x08Transfer\x12\x30\n\x06server\x18\x01 \x03(\x0b\x32 .oak9.tython.aws.transfer.Server\x12,\n\x04user\x18\x02 \x03(\x0b\x32\x1e.oak9.tython.aws.transfer.User\"s\n\x19UserHomeDirectoryMapEntry\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x65ntry\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x01(\t\"K\n\x10UserSshPublicKey\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb8\x03\n\x04User\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06policy\x18\x02 \x01(\t\x12\x0c\n\x04role\x18\x03 \x01(\t\x12\x16\n\x0ehome_directory\x18\x04 \x01(\t\x12\x1b\n\x13home_directory_type\x18\x05 \x01(\t\x12\x11\n\tserver_id\x18\x06 \x01(\t\x12\x11\n\tuser_name\x18\x07 \x01(\t\x12T\n\x17home_directory_mappings\x18\x08 \x03(\x0b\x32\x33.oak9.tython.aws.transfer.UserHomeDirectoryMapEntry\x12\x43\n\x0fssh_public_keys\x18\t \x03(\x0b\x32*.oak9.tython.aws.transfer.UserSshPublicKey\x12\x36\n\x04tags\x18\n \x03(\x0b\x32(.oak9.tython.aws.transfer.User.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_transfer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SERVER_TAGSENTRY._options = None
  _SERVER_TAGSENTRY._serialized_options = b'8\001'
  _USER_TAGSENTRY._options = None
  _USER_TAGSENTRY._serialized_options = b'8\001'
  _SERVERPROTOCOL._serialized_start=73
  _SERVERPROTOCOL._serialized_end=146
  _SERVERIDENTITYPROVIDERDETAILS._serialized_start=148
  _SERVERIDENTITYPROVIDERDETAILS._serialized_end=274
  _SERVERENDPOINTDETAILS._serialized_start=277
  _SERVERENDPOINTDETAILS._serialized_end=450
  _SERVER._serialized_start=453
  _SERVER._serialized_end=977
  _SERVER_TAGSENTRY._serialized_start=934
  _SERVER_TAGSENTRY._serialized_end=977
  _TRANSFER._serialized_start=979
  _TRANSFER._serialized_end=1085
  _USERHOMEDIRECTORYMAPENTRY._serialized_start=1087
  _USERHOMEDIRECTORYMAPENTRY._serialized_end=1202
  _USERSSHPUBLICKEY._serialized_start=1204
  _USERSSHPUBLICKEY._serialized_end=1279
  _USER._serialized_start=1282
  _USER._serialized_end=1722
  _USER_TAGSENTRY._serialized_start=934
  _USER_TAGSENTRY._serialized_end=977
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_cloudtrail.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_cloudtrail.proto\x12\x1aoak9.tython.aws.cloudtrail\x1a\x13shared/shared.proto\"\\\n\x11TrailDataResource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06values\x18\x02 \x03(\t\"\xd0\x01\n\x12TrailEventSelector\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x0e\x64\x61ta_resources\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.cloudtrail.TrailDataResource\x12!\n\x19include_management_events\x18\x03 \x01(\x08\x12\x17\n\x0fread_write_type\x18\x04 \x01(\t\"\xa9\x04\n\x05Trail\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1e\x63loud_watch_logs_log_group_arn\x18\x02 \x01(\t\x12!\n\x19\x63loud_watch_logs_role_arn\x18\x03 \x01(\t\x12\"\n\x1a\x65nable_log_file_validation\x18\x04 \x01(\x08\x12G\n\x0f\x65vent_selectors\x18\x05 \x03(\x0b\x32..oak9.tython.aws.cloudtrail.TrailEventSelector\x12%\n\x1dinclude_global_service_events\x18\x06 \x01(\x08\x12\x12\n\nis_logging\x18\x07 \x01(\x08\x12\x1d\n\x15is_multi_region_trail\x18\x08 \x01(\x08\x12\x12\n\nkms_key_id\x18\t \x01(\t\x12\x16\n\x0es3_bucket_name\x18\n \x01(\t\x12\x15\n\rs3_key_prefix\x18\x0b \x01(\t\x12\x16\n\x0esns_topic_name\x18\x0c \x01(\t\x12\x39\n\x04tags\x18\r \x03(\x0b\x32+.oak9.tython.aws.cloudtrail.Trail.TagsEntry\x12\x12\n\ntrail_name\x18\x0e \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\">\n\nCloudTrail\x12\x30\n\x05trail\x18\x01 \x01(\x0b\x32!.oak9.tython.aws.cloudtrail.Trailb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_cloudtrail_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TRAIL_TAGSENTRY._options = None
  _TRAIL_TAGSENTRY._serialized_options = b'8\001'
  _TRAILDATARESOURCE._serialized_start=77
  _TRAILDATARESOURCE._serialized_end=169
  _TRAILEVENTSELECTOR._serialized_start=172
  _TRAILEVENTSELECTOR._serialized_end=380
  _TRAIL._serialized_start=383
  _TRAIL._serialized_end=936
  _TRAIL_TAGSENTRY._serialized_start=893
  _TRAIL_TAGSENTRY._serialized_end=936
  _CLOUDTRAIL._serialized_start=938
  _CLOUDTRAIL._serialized_end=1000
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeVpnGatewayXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeVpnGatewayXTimeouts = ComputeVpnGatewayXTimeouts

@typing_extensions.final
class ComputeVpnGateway(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    GATEWAY_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    gateway_id: builtins.float
    id: builtins.str
    name: builtins.str
    network: builtins.str
    project: builtins.str
    region: builtins.str
    self_link: builtins.str
    @property
    def timeouts(self) -> global___ComputeVpnGatewayXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        gateway_id: builtins.float = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        timeouts: global___ComputeVpnGatewayXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "description", b"description", "gateway_id", b"gateway_id", "id", b"id", "name", b"name", "network", b"network", "project", b"project", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___ComputeVpnGateway = ComputeVpnGateway

@typing_extensions.final
class ComputeVpnTunnelXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeVpnTunnelXTimeouts = ComputeVpnTunnelXTimeouts

@typing_extensions.final
class ComputeVpnTunnel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DETAILED_STATUS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IKE_VERSION_FIELD_NUMBER: builtins.int
    LOCAL_TRAFFIC_SELECTOR_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PEER_EXTERNAL_GATEWAY_FIELD_NUMBER: builtins.int
    PEER_EXTERNAL_GATEWAY_INTERFACE_FIELD_NUMBER: builtins.int
    PEER_GCP_GATEWAY_FIELD_NUMBER: builtins.int
    PEER_IP_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    REMOTE_TRAFFIC_SELECTOR_FIELD_NUMBER: builtins.int
    ROUTER_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SHARED_SECRET_FIELD_NUMBER: builtins.int
    SHARED_SECRET_HASH_FIELD_NUMBER: builtins.int
    TARGET_VPN_GATEWAY_FIELD_NUMBER: builtins.int
    TUNNEL_ID_FIELD_NUMBER: builtins.int
    VPN_GATEWAY_FIELD_NUMBER: builtins.int
    VPN_GATEWAY_INTERFACE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    detailed_status: builtins.str
    id: builtins.str
    ike_version: builtins.float
    @property
    def local_traffic_selector(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    peer_external_gateway: builtins.str
    peer_external_gateway_interface: builtins.float
    peer_gcp_gateway: builtins.str
    peer_ip: builtins.str
    project: builtins.str
    region: builtins.str
    @property
    def remote_traffic_selector(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    router: builtins.str
    self_link: builtins.str
    shared_secret: builtins.str
    shared_secret_hash: builtins.str
    target_vpn_gateway: builtins.str
    tunnel_id: builtins.str
    vpn_gateway: builtins.str
    vpn_gateway_interface: builtins.float
    @property
    def timeouts(self) -> global___ComputeVpnTunnelXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        detailed_status: builtins.str = ...,
        id: builtins.str = ...,
        ike_version: builtins.float = ...,
        local_traffic_selector: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        peer_external_gateway: builtins.str = ...,
        peer_external_gateway_interface: builtins.float = ...,
        peer_gcp_gateway: builtins.str = ...,
        peer_ip: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        remote_traffic_selector: collections.abc.Iterable[builtins.str] | None = ...,
        router: builtins.str = ...,
        self_link: builtins.str = ...,
        shared_secret: builtins.str = ...,
        shared_secret_hash: builtins.str = ...,
        target_vpn_gateway: builtins.str = ...,
        tunnel_id: builtins.str = ...,
        vpn_gateway: builtins.str = ...,
        vpn_gateway_interface: builtins.float = ...,
        timeouts: global___ComputeVpnTunnelXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "description", b"description", "detailed_status", b"detailed_status", "id", b"id", "ike_version", b"ike_version", "local_traffic_selector", b"local_traffic_selector", "name", b"name", "peer_external_gateway", b"peer_external_gateway", "peer_external_gateway_interface", b"peer_external_gateway_interface", "peer_gcp_gateway", b"peer_gcp_gateway", "peer_ip", b"peer_ip", "project", b"project", "region", b"region", "remote_traffic_selector", b"remote_traffic_selector", "resource_info", b"resource_info", "router", b"router", "self_link", b"self_link", "shared_secret", b"shared_secret", "shared_secret_hash", b"shared_secret_hash", "target_vpn_gateway", b"target_vpn_gateway", "timeouts", b"timeouts", "tunnel_id", b"tunnel_id", "vpn_gateway", b"vpn_gateway", "vpn_gateway_interface", b"vpn_gateway_interface"]) -> None: ...

global___ComputeVpnTunnel = ComputeVpnTunnel



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_monitoring.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gcp/gcp_monitoring.proto\x12\x1aoak9.tython.gcp.monitoring\x1a\x13shared/shared.proto\"K\n9MonitoringAlertPolicyXAlertStrategyXNotificationRateLimit\x12\x0e\n\x06period\x18\x01 \x01(\t\"\xb1\x01\n#MonitoringAlertPolicyXAlertStrategy\x12\x12\n\nauto_close\x18\x01 \x01(\t\x12v\n\x17notification_rate_limit\x18\x02 \x01(\x0b\x32U.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXAlertStrategyXNotificationRateLimit\"\xac\x01\n=MonitoringAlertPolicyXConditionsXConditionAbsentXAggregations\x12\x18\n\x10\x61lignment_period\x18\x01 \x01(\t\x12\x1c\n\x14\x63ross_series_reducer\x18\x02 \x01(\t\x12\x17\n\x0fgroup_by_fields\x18\x03 \x03(\t\x12\x1a\n\x12per_series_aligner\x18\x04 \x01(\t\"Z\n8MonitoringAlertPolicyXConditionsXConditionAbsentXTrigger\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12\x0f\n\x07percent\x18\x02 \x01(\x01\"\xac\x02\n0MonitoringAlertPolicyXConditionsXConditionAbsent\x12\x10\n\x08\x64uration\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12o\n\x0c\x61ggregations\x18\x03 \x03(\x0b\x32Y.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionAbsentXAggregations\x12\x65\n\x07trigger\x18\x04 \x01(\x0b\x32T.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionAbsentXTrigger\"\xff\x01\n4MonitoringAlertPolicyXConditionsXConditionMatchedLog\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\x12\x7f\n\x10label_extractors\x18\x02 \x03(\x0b\x32\x65.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionMatchedLog.LabelExtractorsEntry\x1a\x36\n\x14LabelExtractorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"k\nIMonitoringAlertPolicyXConditionsXConditionMonitoringQueryLanguageXTrigger\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12\x0f\n\x07percent\x18\x02 \x01(\x01\"\xfd\x01\nAMonitoringAlertPolicyXConditionsXConditionMonitoringQueryLanguage\x12\x10\n\x08\x64uration\x18\x01 \x01(\t\x12\x1f\n\x17\x65valuation_missing_data\x18\x02 \x01(\t\x12\r\n\x05query\x18\x03 \x01(\t\x12v\n\x07trigger\x18\x04 \x01(\x0b\x32\x65.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionMonitoringQueryLanguageXTrigger\"\xaf\x01\n@MonitoringAlertPolicyXConditionsXConditionThresholdXAggregations\x12\x18\n\x10\x61lignment_period\x18\x01 \x01(\t\x12\x1c\n\x14\x63ross_series_reducer\x18\x02 \x01(\t\x12\x17\n\x0fgroup_by_fields\x18\x03 \x03(\t\x12\x1a\n\x12per_series_aligner\x18\x04 \x01(\t\"\xba\x01\nKMonitoringAlertPolicyXConditionsXConditionThresholdXDenominatorAggregations\x12\x18\n\x10\x61lignment_period\x18\x01 \x01(\t\x12\x1c\n\x14\x63ross_series_reducer\x18\x02 \x01(\t\x12\x17\n\x0fgroup_by_fields\x18\x03 \x03(\t\x12\x1a\n\x12per_series_aligner\x18\x04 \x01(\t\"]\n;MonitoringAlertPolicyXConditionsXConditionThresholdXTrigger\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12\x0f\n\x07percent\x18\x02 \x01(\x01\"\xab\x04\n3MonitoringAlertPolicyXConditionsXConditionThreshold\x12\x12\n\ncomparison\x18\x01 \x01(\t\x12\x1a\n\x12\x64\x65nominator_filter\x18\x02 \x01(\t\x12\x10\n\x08\x64uration\x18\x03 \x01(\t\x12\x1f\n\x17\x65valuation_missing_data\x18\x04 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x05 \x01(\t\x12\x17\n\x0fthreshold_value\x18\x06 \x01(\x01\x12r\n\x0c\x61ggregations\x18\x07 \x03(\x0b\x32\\.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionThresholdXAggregations\x12\x89\x01\n\x18\x64\x65nominator_aggregations\x18\x08 \x03(\x0b\x32g.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionThresholdXDenominatorAggregations\x12h\n\x07trigger\x18\t \x01(\x0b\x32W.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionThresholdXTrigger\"\x9a\x04\n MonitoringAlertPolicyXConditions\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x66\n\x10\x63ondition_absent\x18\x03 \x01(\x0b\x32L.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionAbsent\x12o\n\x15\x63ondition_matched_log\x18\x04 \x01(\x0b\x32P.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionMatchedLog\x12\x8a\x01\n#condition_monitoring_query_language\x18\x05 \x01(\x0b\x32].oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionMonitoringQueryLanguage\x12l\n\x13\x63ondition_threshold\x18\x06 \x01(\x0b\x32O.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditionsXConditionThreshold\"I\n#MonitoringAlertPolicyXDocumentation\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x11\n\tmime_type\x18\x02 \x01(\t\"P\n\x1eMonitoringAlertPolicyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc6\x06\n\x15MonitoringAlertPolicy\x12\x10\n\x08\x63ombiner\x18\x01 \x01(\t\x12^\n\x0f\x63reation_record\x18\x02 \x03(\x0b\x32\x45.oak9.tython.gcp.monitoring.MonitoringAlertPolicy.CreationRecordEntry\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x1d\n\x15notification_channels\x18\x07 \x03(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12V\n\x0buser_labels\x18\t \x03(\x0b\x32\x41.oak9.tython.gcp.monitoring.MonitoringAlertPolicy.UserLabelsEntry\x12W\n\x0e\x61lert_strategy\x18\n \x01(\x0b\x32?.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXAlertStrategy\x12P\n\nconditions\x18\x0b \x03(\x0b\x32<.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXConditions\x12V\n\rdocumentation\x18\x0c \x01(\x0b\x32?.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXDocumentation\x12L\n\x08timeouts\x18\r \x01(\x0b\x32:.oak9.tython.gcp.monitoring.MonitoringAlertPolicyXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x35\n\x13\x43reationRecordEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fUserLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n!MonitoringCustomServiceXTelemetry\x12\x15\n\rresource_name\x18\x01 \x01(\t\"R\n MonitoringCustomServiceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd6\x03\n\x17MonitoringCustomService\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x12\n\nservice_id\x18\x05 \x01(\t\x12X\n\x0buser_labels\x18\x06 \x03(\x0b\x32\x43.oak9.tython.gcp.monitoring.MonitoringCustomService.UserLabelsEntry\x12P\n\ttelemetry\x18\x07 \x01(\x0b\x32=.oak9.tython.gcp.monitoring.MonitoringCustomServiceXTelemetry\x12N\n\x08timeouts\x18\x08 \x01(\x0b\x32<.oak9.tython.gcp.monitoring.MonitoringCustomServiceXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x31\n\x0fUserLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"N\n\x1cMonitoringDashboardXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xcf\x01\n\x13MonitoringDashboard\x12\x16\n\x0e\x64\x61shboard_json\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12J\n\x08timeouts\x18\x04 \x01(\x0b\x32\x38.oak9.tython.gcp.monitoring.MonitoringDashboardXTimeouts\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"J\n\x18MonitoringGroupXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x8c\x02\n\x0fMonitoringGroup\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x12\n\nis_cluster\x18\x04 \x01(\x08\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0bparent_name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x46\n\x08timeouts\x18\x08 \x01(\x0b\x32\x34.oak9.tython.gcp.monitoring.MonitoringGroupXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Y\n!MonitoringMetricDescriptorXLabels\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x12\n\nvalue_type\x18\x03 \x01(\t\"R\n#MonitoringMetricDescriptorXMetadata\x12\x14\n\x0cingest_delay\x18\x01 \x01(\t\x12\x15\n\rsample_period\x18\x02 \x01(\t\"U\n#MonitoringMetricDescriptorXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x9d\x04\n\x1aMonitoringMetricDescriptor\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x14\n\x0claunch_stage\x18\x04 \x01(\t\x12\x13\n\x0bmetric_kind\x18\x05 \x01(\t\x12 \n\x18monitored_resource_types\x18\x06 \x03(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x0c\n\x04type\x18\t \x01(\t\x12\x0c\n\x04unit\x18\n \x01(\t\x12\x12\n\nvalue_type\x18\x0b \x01(\t\x12M\n\x06labels\x18\x0c \x03(\x0b\x32=.oak9.tython.gcp.monitoring.MonitoringMetricDescriptorXLabels\x12Q\n\x08metadata\x18\r \x01(\x0b\x32?.oak9.tython.gcp.monitoring.MonitoringMetricDescriptorXMetadata\x12Q\n\x08timeouts\x18\x0e \x01(\x0b\x32?.oak9.tython.gcp.monitoring.MonitoringMetricDescriptorXTimeouts\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"E\n#MonitoringMonitoredProjectXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xee\x01\n\x1aMonitoringMonitoredProject\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\rmetrics_scope\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12Q\n\x08timeouts\x18\x05 \x01(\x0b\x32?.oak9.tython.gcp.monitoring.MonitoringMonitoredProjectXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"j\n-MonitoringNotificationChannelXSensitiveLabels\x12\x12\n\nauth_token\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x13\n\x0bservice_key\x18\x03 \x01(\t\"X\n&MonitoringNotificationChannelXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xbe\x05\n\x1dMonitoringNotificationChannel\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12U\n\x06labels\x18\x05 \x03(\x0b\x32\x45.oak9.tython.gcp.monitoring.MonitoringNotificationChannel.LabelsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\x12^\n\x0buser_labels\x18\t \x03(\x0b\x32I.oak9.tython.gcp.monitoring.MonitoringNotificationChannel.UserLabelsEntry\x12\x1b\n\x13verification_status\x18\n \x01(\t\x12\x63\n\x10sensitive_labels\x18\x0b \x01(\x0b\x32I.oak9.tython.gcp.monitoring.MonitoringNotificationChannelXSensitiveLabels\x12T\n\x08timeouts\x18\x0c \x01(\x0b\x32\x42.oak9.tython.gcp.monitoring.MonitoringNotificationChannelXTimeouts\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fUserLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n#MonitoringSloXBasicSliXAvailability\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"3\n\x1eMonitoringSloXBasicSliXLatency\x12\x11\n\tthreshold\x18\x01 \x01(\t\"\xef\x01\n\x16MonitoringSloXBasicSli\x12\x10\n\x08location\x18\x01 \x03(\t\x12\x0e\n\x06method\x18\x02 \x03(\t\x12\x0f\n\x07version\x18\x03 \x03(\t\x12U\n\x0c\x61vailability\x18\x04 \x01(\x0b\x32?.oak9.tython.gcp.monitoring.MonitoringSloXBasicSliXAvailability\x12K\n\x07latency\x18\x05 \x01(\x0b\x32:.oak9.tython.gcp.monitoring.MonitoringSloXBasicSliXLatency\"O\n3MonitoringSloXRequestBasedSliXDistributionCutXRange\x12\x0b\n\x03max\x18\x01 \x01(\x01\x12\x0b\n\x03min\x18\x02 \x01(\x01\"\xac\x01\n-MonitoringSloXRequestBasedSliXDistributionCut\x12\x1b\n\x13\x64istribution_filter\x18\x01 \x01(\t\x12^\n\x05range\x18\x02 \x01(\x0b\x32O.oak9.tython.gcp.monitoring.MonitoringSloXRequestBasedSliXDistributionCutXRange\"\x85\x01\n,MonitoringSloXRequestBasedSliXGoodTotalRatio\x12\x1a\n\x12\x62\x61\x64_service_filter\x18\x01 \x01(\t\x12\x1b\n\x13good_service_filter\x18\x02 \x01(\t\x12\x1c\n\x14total_service_filter\x18\x03 \x01(\t\"\xe8\x01\n\x1dMonitoringSloXRequestBasedSli\x12\x63\n\x10\x64istribution_cut\x18\x01 \x01(\x0b\x32I.oak9.tython.gcp.monitoring.MonitoringSloXRequestBasedSliXDistributionCut\x12\x62\n\x10good_total_ratio\x18\x02 \x01(\x0b\x32H.oak9.tython.gcp.monitoring.MonitoringSloXRequestBasedSliXGoodTotalRatio\"H\n\x16MonitoringSloXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"i\nVMonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXBasicSliPerformanceXAvailability\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"f\nQMonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXBasicSliPerformanceXLatency\x12\x11\n\tthreshold\x18\x01 \x01(\t\"\x89\x03\nIMonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXBasicSliPerformance\x12\x10\n\x08location\x18\x01 \x03(\t\x12\x0e\n\x06method\x18\x02 \x03(\t\x12\x0f\n\x07version\x18\x03 \x03(\t\x12\x88\x01\n\x0c\x61vailability\x18\x04 \x01(\x0b\x32r.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXBasicSliPerformanceXAvailability\x12~\n\x07latency\x18\x05 \x01(\x0b\x32m.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXBasicSliPerformanceXLatency\"s\nWMonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXPerformanceXDistributionCutXRange\x12\x0b\n\x03max\x18\x01 \x01(\x01\x12\x0b\n\x03min\x18\x02 \x01(\x01\"\xf5\x01\nQMonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXPerformanceXDistributionCut\x12\x1b\n\x13\x64istribution_filter\x18\x01 \x01(\t\x12\x82\x01\n\x05range\x18\x02 \x01(\x0b\x32s.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXPerformanceXDistributionCutXRange\"\xa9\x01\nPMonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXPerformanceXGoodTotalRatio\x12\x1a\n\x12\x62\x61\x64_service_filter\x18\x01 \x01(\t\x12\x1b\n\x13good_service_filter\x18\x02 \x01(\t\x12\x1c\n\x14total_service_filter\x18\x03 \x01(\t\"\xd6\x02\nAMonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXPerformance\x12\x87\x01\n\x10\x64istribution_cut\x18\x01 \x01(\x0b\x32m.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXPerformanceXDistributionCut\x12\x86\x01\n\x10good_total_ratio\x18\x02 \x01(\x0b\x32l.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXPerformanceXGoodTotalRatio\"\xc5\x02\n5MonitoringSloXWindowsBasedSliXGoodTotalRatioThreshold\x12\x11\n\tthreshold\x18\x01 \x01(\x01\x12\x84\x01\n\x15\x62\x61sic_sli_performance\x18\x02 \x01(\x0b\x32\x65.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXBasicSliPerformance\x12r\n\x0bperformance\x18\x03 \x01(\x0b\x32].oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXGoodTotalRatioThresholdXPerformance\"Q\n5MonitoringSloXWindowsBasedSliXMetricMeanInRangeXRange\x12\x0b\n\x03max\x18\x01 \x01(\x01\x12\x0b\n\x03min\x18\x02 \x01(\x01\"\xa8\x01\n/MonitoringSloXWindowsBasedSliXMetricMeanInRange\x12\x13\n\x0btime_series\x18\x01 \x01(\t\x12`\n\x05range\x18\x02 \x01(\x0b\x32Q.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXMetricMeanInRangeXRange\"P\n4MonitoringSloXWindowsBasedSliXMetricSumInRangeXRange\x12\x0b\n\x03max\x18\x01 \x01(\x01\x12\x0b\n\x03min\x18\x02 \x01(\x01\"\xa6\x01\n.MonitoringSloXWindowsBasedSliXMetricSumInRange\x12\x13\n\x0btime_series\x18\x01 \x01(\t\x12_\n\x05range\x18\x02 \x01(\x0b\x32P.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXMetricSumInRangeXRange\"\xa1\x03\n\x1dMonitoringSloXWindowsBasedSli\x12\x1e\n\x16good_bad_metric_filter\x18\x01 \x01(\t\x12\x15\n\rwindow_period\x18\x02 \x01(\t\x12u\n\x1agood_total_ratio_threshold\x18\x03 \x01(\x0b\x32Q.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXGoodTotalRatioThreshold\x12i\n\x14metric_mean_in_range\x18\x04 \x01(\x0b\x32K.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXMetricMeanInRange\x12g\n\x13metric_sum_in_range\x18\x05 \x01(\x0b\x32J.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSliXMetricSumInRange\"\xaa\x05\n\rMonitoringSlo\x12\x17\n\x0f\x63\x61lendar_period\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x0c\n\x04goal\x18\x03 \x01(\x01\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x1b\n\x13rolling_period_days\x18\x07 \x01(\x01\x12\x0f\n\x07service\x18\x08 \x01(\t\x12\x0e\n\x06slo_id\x18\t \x01(\t\x12N\n\x0buser_labels\x18\n \x03(\x0b\x32\x39.oak9.tython.gcp.monitoring.MonitoringSlo.UserLabelsEntry\x12\x45\n\tbasic_sli\x18\x0b \x01(\x0b\x32\x32.oak9.tython.gcp.monitoring.MonitoringSloXBasicSli\x12T\n\x11request_based_sli\x18\x0c \x01(\x0b\x32\x39.oak9.tython.gcp.monitoring.MonitoringSloXRequestBasedSli\x12\x44\n\x08timeouts\x18\r \x01(\x0b\x32\x32.oak9.tython.gcp.monitoring.MonitoringSloXTimeouts\x12T\n\x11windows_based_sli\x18\x0e \x01(\x0b\x32\x39.oak9.tython.gcp.monitoring.MonitoringSloXWindowsBasedSli\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x31\n\x0fUserLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"f\n;MonitoringUptimeCheckConfigXContentMatchersXJsonPathMatcher\x12\x14\n\x0cjson_matcher\x18\x01 \x01(\t\x12\x11\n\tjson_path\x18\x02 \x01(\t\"\xc3\x01\n+MonitoringUptimeCheckConfigXContentMatchers\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x0f\n\x07matcher\x18\x02 \x01(\t\x12r\n\x11json_path_matcher\x18\x03 \x01(\x0b\x32W.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXContentMatchersXJsonPathMatcher\"T\n.MonitoringUptimeCheckConfigXHttpCheckXAuthInfo\x12\x10\n\x08password\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\"\xac\x03\n%MonitoringUptimeCheckConfigXHttpCheck\x12\x0c\n\x04\x62ody\x18\x01 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x02 \x01(\t\x12_\n\x07headers\x18\x03 \x03(\x0b\x32N.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXHttpCheck.HeadersEntry\x12\x14\n\x0cmask_headers\x18\x04 \x01(\x08\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x0c\n\x04port\x18\x06 \x01(\x01\x12\x16\n\x0erequest_method\x18\x07 \x01(\t\x12\x0f\n\x07use_ssl\x18\x08 \x01(\x08\x12\x14\n\x0cvalidate_ssl\x18\t \x01(\x08\x12]\n\tauth_info\x18\n \x01(\x0b\x32J.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXHttpCheckXAuthInfo\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd3\x01\n-MonitoringUptimeCheckConfigXMonitoredResource\x12\x65\n\x06labels\x18\x01 \x03(\x0b\x32U.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXMonitoredResource.LabelsEntry\x12\x0c\n\x04type\x18\x02 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"T\n)MonitoringUptimeCheckConfigXResourceGroup\x12\x10\n\x08group_id\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\"4\n$MonitoringUptimeCheckConfigXTcpCheck\x12\x0c\n\x04port\x18\x01 \x01(\x01\"V\n$MonitoringUptimeCheckConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xaa\x06\n\x1bMonitoringUptimeCheckConfig\x12\x14\n\x0c\x63hecker_type\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06period\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x18\n\x10selected_regions\x18\x07 \x03(\t\x12\x0f\n\x07timeout\x18\x08 \x01(\t\x12\x17\n\x0fuptime_check_id\x18\t \x01(\t\x12\x61\n\x10\x63ontent_matchers\x18\n \x03(\x0b\x32G.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXContentMatchers\x12U\n\nhttp_check\x18\x0b \x01(\x0b\x32\x41.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXHttpCheck\x12\x65\n\x12monitored_resource\x18\x0c \x01(\x0b\x32I.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXMonitoredResource\x12]\n\x0eresource_group\x18\r \x01(\x0b\x32\x45.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXResourceGroup\x12S\n\ttcp_check\x18\x0e \x01(\x0b\x32@.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXTcpCheck\x12R\n\x08timeouts\x18\x0f \x01(\x0b\x32@.oak9.tython.gcp.monitoring.MonitoringUptimeCheckConfigXTimeouts\x12\x37\n\rresource_info\x18\x10 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_monitoring_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMATCHEDLOG_LABELEXTRACTORSENTRY._options = None
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMATCHEDLOG_LABELEXTRACTORSENTRY._serialized_options = b'8\001'
  _MONITORINGALERTPOLICY_CREATIONRECORDENTRY._options = None
  _MONITORINGALERTPOLICY_CREATIONRECORDENTRY._serialized_options = b'8\001'
  _MONITORINGALERTPOLICY_USERLABELSENTRY._options = None
  _MONITORINGALERTPOLICY_USERLABELSENTRY._serialized_options = b'8\001'
  _MONITORINGCUSTOMSERVICE_USERLABELSENTRY._options = None
  _MONITORINGCUSTOMSERVICE_USERLABELSENTRY._serialized_options = b'8\001'
  _MONITORINGNOTIFICATIONCHANNEL_LABELSENTRY._options = None
  _MONITORINGNOTIFICATIONCHANNEL_LABELSENTRY._serialized_options = b'8\001'
  _MONITORINGNOTIFICATIONCHANNEL_USERLABELSENTRY._options = None
  _MONITORINGNOTIFICATIONCHANNEL_USERLABELSENTRY._serialized_options = b'8\001'
  _MONITORINGSLO_USERLABELSENTRY._options = None
  _MONITORINGSLO_USERLABELSENTRY._serialized_options = b'8\001'
  _MONITORINGUPTIMECHECKCONFIGXHTTPCHECK_HEADERSENTRY._options = None
  _MONITORINGUPTIMECHECKCONFIGXHTTPCHECK_HEADERSENTRY._serialized_options = b'8\001'
  _MONITORINGUPTIMECHECKCONFIGXMONITOREDRESOURCE_LABELSENTRY._options = None
  _MONITORINGUPTIMECHECKCONFIGXMONITOREDRESOURCE_LABELSENTRY._serialized_options = b'8\001'
  _MONITORINGALERTPOLICYXALERTSTRATEGYXNOTIFICATIONRATELIMIT._serialized_start=77
  _MONITORINGALERTPOLICYXALERTSTRATEGYXNOTIFICATIONRATELIMIT._serialized_end=152
  _MONITORINGALERTPOLICYXALERTSTRATEGY._serialized_start=155
  _MONITORINGALERTPOLICYXALERTSTRATEGY._serialized_end=332
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONABSENTXAGGREGATIONS._serialized_start=335
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONABSENTXAGGREGATIONS._serialized_end=507
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONABSENTXTRIGGER._serialized_start=509
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONABSENTXTRIGGER._serialized_end=599
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONABSENT._serialized_start=602
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONABSENT._serialized_end=902
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMATCHEDLOG._serialized_start=905
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMATCHEDLOG._serialized_end=1160
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMATCHEDLOG_LABELEXTRACTORSENTRY._serialized_start=1106
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMATCHEDLOG_LABELEXTRACTORSENTRY._serialized_end=1160
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMONITORINGQUERYLANGUAGEXTRIGGER._serialized_start=1162
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMONITORINGQUERYLANGUAGEXTRIGGER._serialized_end=1269
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMONITORINGQUERYLANGUAGE._serialized_start=1272
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONMONITORINGQUERYLANGUAGE._serialized_end=1525
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONTHRESHOLDXAGGREGATIONS._serialized_start=1528
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONTHRESHOLDXAGGREGATIONS._serialized_end=1703
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONTHRESHOLDXDENOMINATORAGGREGATIONS._serialized_start=1706
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONTHRESHOLDXDENOMINATORAGGREGATIONS._serialized_end=1892
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONTHRESHOLDXTRIGGER._serialized_start=1894
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONTHRESHOLDXTRIGGER._serialized_end=1987
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONTHRESHOLD._serialized_start=1990
  _MONITORINGALERTPOLICYXCONDITIONSXCONDITIONTHRESHOLD._serialized_end=2545
  _MONITORINGALERTPOLICYXCONDITIONS._serialized_start=2548
  _MONITORINGALERTPOLICYXCONDITIONS._serialized_end=3086
  _MONITORINGALERTPOLICYXDOCUMENTATION._serialized_start=3088
  _MONITORINGALERTPOLICYXDOCUMENTATION._serialized_end=3161
  _MONITORINGALERTPOLICYXTIMEOUTS._serialized_start=3163
  _MONITORINGALERTPOLICYXTIMEOUTS._serialized_end=3243
  _MONITORINGALERTPOLICY._serialized_start=3246
  _MONITORINGALERTPOLICY._serialized_end=4084
  _MONITORINGALERTPOLICY_CREATIONRECORDENTRY._serialized_start=3980
  _MONITORINGALERTPOLICY_CREATIONRECORDENTRY._serialized_end=4033
  _MONITORINGALERTPOLICY_USERLABELSENTRY._serialized_start=4035
  _MONITORINGALERTPOLICY_USERLABELSENTRY._serialized_end=4084
  _MONITORINGCUSTOMSERVICEXTELEMETRY._serialized_start=4086
  _MONITORINGCUSTOMSERVICEXTELEMETRY._serialized_end=4144
  _MONITORINGCUSTOMSERVICEXTIMEOUTS._serialized_start=4146
  _MONITORINGCUSTOMSERVICEXTIMEOUTS._serialized_end=4228
  _MONITORINGCUSTOMSERVICE._serialized_start=4231
  _MONITORINGCUSTOMSERVICE._serialized_end=4701
  _MONITORINGCUSTOMSERVICE_USERLABELSENTRY._serialized_start=4035
  _MONITORINGCUSTOMSERVICE_USERLABELSENTRY._serialized_end=4084
  _MONITORINGDASHBOARDXTIMEOUTS._serialized_start=4703
  _MONITORINGDASHBOARDXTIMEOUTS._serialized_end=4781
  _MONITORINGDASHBOARD._serialized_start=4784
  _MONITORINGDASHBOARD._serialized_end=4991
  _MONITORINGGROUPXTIMEOUTS._serialized_start=4993
  _MONITORINGGROUPXTIMEOUTS._serialized_end=5067
  _MONITORINGGROUP._serialized_start=5070
  _MONITORINGGROUP._serialized_end=5338
  _MONITORINGMETRICDESCRIPTORXLABELS._serialized_start=5340
  _MONITORINGMETRICDESCRIPTORXLABELS._serialized_end=5429
  _MONITORINGMETRICDESCRIPTORXMETADATA._serialized_start=5431
  _MONITORINGMETRICDESCRIPTORXMETADATA._serialized_end=5513
  _MONITORINGMETRICDESCRIPTORXTIMEOUTS._serialized_start=5515
  _MONITORINGMETRICDESCRIPTORXTIMEOUTS._serialized_end=5600
  _MONITORINGMETRICDESCRIPTOR._serialized_start=5603
  _MONITORINGMETRICDESCRIPTOR._serialized_end=6144
  _MONITORINGMONITOREDPROJECTXTIMEOUTS._serialized_start=6146
  _MONITORINGMONITOREDPROJECTXTIMEOUTS._serialized_end=6215
  _MONITORINGMONITOREDPROJECT._serialized_start=6218
  _MONITORINGMONITOREDPROJECT._serialized_end=6456
  _MONITORINGNOTIFICATIONCHANNELXSENSITIVELABELS._serialized_start=6458
  _MONITORINGNOTIFICATIONCHANNELXSENSITIVELABELS._serialized_end=6564
  _MONITORINGNOTIFICATIONCHANNELXTIMEOUTS._serialized_start=6566
  _MONITORINGNOTIFICATIONCHANNELXTIMEOUTS._serialized_end=6654
  _MONITORINGNOTIFICATIONCHANNEL._serialized_start=6657
  _MONITORINGNOTIFICATIONCHANNEL._serialized_end=7359
  _MONITORINGNOTIFICATIONCHANNEL_LABELSENTRY._serialized_start=7263
  _MONITORINGNOTIFICATIONCHANNEL_LABELSENTRY._serialized_end=7308
  _MONITORINGNOTIFICATIONCHANNEL_USERLABELSENTRY._serialized_start=4035
  _MONITORINGNOTIFICATIONCHANNEL_USERLABELSENTRY._serialized_end=4084
  _MONITORINGSLOXBASICSLIXAVAILABILITY._serialized_start=7361
  _MONITORINGSLOXBASICSLIXAVAILABILITY._serialized_end=7415
  _MONITORINGSLOXBASICSLIXLATENCY._serialized_start=7417
  _MONITORINGSLOXBASICSLIXLATENCY._serialized_end=7468
  _MONITORINGSLOXBASICSLI._serialized_start=7471
  _MONITORINGSLOXBASICSLI._serialized_end=7710
  _MONITORINGSLOXREQUESTBASEDSLIXDISTRIBUTIONCUTXRANGE._serialized_start=7712
  _MONITORINGSLOXREQUESTBASEDSLIXDISTRIBUTIONCUTXRANGE._serialized_end=7791
  _MONITORINGSLOXREQUESTBASEDSLIXDISTRIBUTIONCUT._serialized_start=7794
  _MONITORINGSLOXREQUESTBASEDSLIXDISTRIBUTIONCUT._serialized_end=7966
  _MONITORINGSLOXREQUESTBASEDSLIXGOODTOTALRATIO._serialized_start=7969
  _MONITORINGSLOXREQUESTBASEDSLIXGOODTOTALRATIO._serialized_end=8102
  _MONITORINGSLOXREQUESTBASEDSLI._serialized_start=8105
  _MONITORINGSLOXREQUESTBASEDSLI._serialized_end=8337
  _MONITORINGSLOXTIMEOUTS._serialized_start=8339
  _MONITORINGSLOXTIMEOUTS._serialized_end=8411
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXBASICSLIPERFORMANCEXAVAILABILITY._serialized_start=8413
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXBASICSLIPERFORMANCEXAVAILABILITY._serialized_end=8518
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXBASICSLIPERFORMANCEXLATENCY._serialized_start=8520
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXBASICSLIPERFORMANCEXLATENCY._serialized_end=8622
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXBASICSLIPERFORMANCE._serialized_start=8625
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXBASICSLIPERFORMANCE._serialized_end=9018
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXPERFORMANCEXDISTRIBUTIONCUTXRANGE._serialized_start=9020
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXPERFORMANCEXDISTRIBUTIONCUTXRANGE._serialized_end=9135
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXPERFORMANCEXDISTRIBUTIONCUT._serialized_start=9138
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXPERFORMANCEXDISTRIBUTIONCUT._serialized_end=9383
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXPERFORMANCEXGOODTOTALRATIO._serialized_start=9386
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXPERFORMANCEXGOODTOTALRATIO._serialized_end=9555
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXPERFORMANCE._serialized_start=9558
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLDXPERFORMANCE._serialized_end=9900
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLD._serialized_start=9903
  _MONITORINGSLOXWINDOWSBASEDSLIXGOODTOTALRATIOTHRESHOLD._serialized_end=10228
  _MONITORINGSLOXWINDOWSBASEDSLIXMETRICMEANINRANGEXRANGE._serialized_start=10230
  _MONITORINGSLOXWINDOWSBASEDSLIXMETRICMEANINRANGEXRANGE._serialized_end=10311
  _MONITORINGSLOXWINDOWSBASEDSLIXMETRICMEANINRANGE._serialized_start=10314
  _MONITORINGSLOXWINDOWSBASEDSLIXMETRICMEANINRANGE._serialized_end=10482
  _MONITORINGSLOXWINDOWSBASEDSLIXMETRICSUMINRANGEXRANGE._serialized_start=10484
  _MONITORINGSLOXWINDOWSBASEDSLIXMETRICSUMINRANGEXRANGE._serialized_end=10564
  _MONITORINGSLOXWINDOWSBASEDSLIXMETRICSUMINRANGE._serialized_start=10567
  _MONITORINGSLOXWINDOWSBASEDSLIXMETRICSUMINRANGE._serialized_end=10733
  _MONITORINGSLOXWINDOWSBASEDSLI._serialized_start=10736
  _MONITORINGSLOXWINDOWSBASEDSLI._serialized_end=11153
  _MONITORINGSLO._serialized_start=11156
  _MONITORINGSLO._serialized_end=11838
  _MONITORINGSLO_USERLABELSENTRY._serialized_start=4035
  _MONITORINGSLO_USERLABELSENTRY._serialized_end=4084
  _MONITORINGUPTIMECHECKCONFIGXCONTENTMATCHERSXJSONPATHMATCHER._serialized_start=11840
  _MONITORINGUPTIMECHECKCONFIGXCONTENTMATCHERSXJSONPATHMATCHER._serialized_end=11942
  _MONITORINGUPTIMECHECKCONFIGXCONTENTMATCHERS._serialized_start=11945
  _MONITORINGUPTIMECHECKCONFIGXCONTENTMATCHERS._serialized_end=12140
  _MONITORINGUPTIMECHECKCONFIGXHTTPCHECKXAUTHINFO._serialized_start=12142
  _MONITORINGUPTIMECHECKCONFIGXHTTPCHECKXAUTHINFO._serialized_end=12226
  _MONITORINGUPTIMECHECKCONFIGXHTTPCHECK._serialized_start=12229
  _MONITORINGUPTIMECHECKCONFIGXHTTPCHECK._serialized_end=12657
  _MONITORINGUPTIMECHECKCONFIGXHTTPCHECK_HEADERSENTRY._serialized_start=12611
  _MONITORINGUPTIMECHECKCONFIGXHTTPCHECK_HEADERSENTRY._serialized_end=12657
  _MONITORINGUPTIMECHECKCONFIGXMONITOREDRESOURCE._serialized_start=12660
  _MONITORINGUPTIMECHECKCONFIGXMONITOREDRESOURCE._serialized_end=12871
  _MONITORINGUPTIMECHECKCONFIGXMONITOREDRESOURCE_LABELSENTRY._serialized_start=7263
  _MONITORINGUPTIMECHECKCONFIGXMONITOREDRESOURCE_LABELSENTRY._serialized_end=7308
  _MONITORINGUPTIMECHECKCONFIGXRESOURCEGROUP._serialized_start=12873
  _MONITORINGUPTIMECHECKCONFIGXRESOURCEGROUP._serialized_end=12957
  _MONITORINGUPTIMECHECKCONFIGXTCPCHECK._serialized_start=12959
  _MONITORINGUPTIMECHECKCONFIGXTCPCHECK._serialized_end=13011
  _MONITORINGUPTIMECHECKCONFIGXTIMEOUTS._serialized_start=13013
  _MONITORINGUPTIMECHECKCONFIGXTIMEOUTS._serialized_end=13099
  _MONITORINGUPTIMECHECKCONFIG._serialized_start=13102
  _MONITORINGUPTIMECHECKCONFIG._serialized_end=13912
# @@protoc_insertion_point(module_scope)
